@@ -13,25 +13,24 @@
     *                                                                       *
     *************************************************************************
 */
+#include "cwsearchwidget.h"
 
-#include <qpushbutton.h>
+#include <QPushButton>
 #include <klocale.h>
 #include <kdialog.h>
-#include <qlineedit.h>
-#include <qlayout.h>
+#include <QLineEdit>
+#include <QLayout>
 #include <kcombobox.h>
-#include <qlabel.h>
-
-#include "cwsearchwidget.h"
+#include <QLabel>
 
 using namespace KBugBusterMainWindow;
 
-CWSearchWidget::CWSearchWidget( QWidget *parent , const char * name )
-: CWSearchWidget_Base( parent, name )
+CWSearchWidget::CWSearchWidget( QWidget *parent )
+: CWSearchWidget_Base( parent )
 {
     // Set fonts and margins
-    CWSearchWidget_BaseLayout->setSpacing( KDialog::spacingHint() );
-    CWSearchWidget_BaseLayout->setMargin( KDialog::marginHint() );
+    //CWSearchWidget_Base->setSpacing( KDialog::spacingHint() );
+    //CWSearchWidget_Base->setMargin( KDialog::marginHint() );
 
     QFont f = m_searchLabel->font();
     f.setBold( true );
