@@ -1,15 +1,16 @@
-#include <qintdict.h>
+#include <q3intdict.h>
 #include <stdio.h>
 #include <qstringlist.h>
-#include <qstrlist.h>
+#include <q3strlist.h>
 #include <qtextstream.h>
-#include <qsortedlist.h>
+#include <q3sortedlist.h>
 #include <qfile.h>
-#include <qtl.h>
-#include <qvaluelist.h>
+#include <q3tl.h>
+#include <q3dict.h>
+#include <q3valuelist.h>
 #include <stdlib.h>
-#include <ktempfile.h>
-#include <kinstance.h>
+#include <ktemporaryfile.h>
+#include <kcomponentdata.h>
 #include <kstandarddirs.h>
 #include <kcmdlineargs.h>
 
@@ -26,9 +27,9 @@ int main(int argc, char **argv)
                       "in <map-file>, in the same order as they appear in <call-file>.\n");
       return 1;
    }
-   
+
    int i = 1;
-   QDict<int> dict(20011);
+   Q3Dict<int> dict(20011);
 
    FILE *map_file = fopen(argv[1], "r");
    if (!map_file)
@@ -39,35 +40,35 @@ int main(int argc, char **argv)
    while(!feof(map_file))
    {
       fgets(buf, 1024, map_file);
-      QString line = QString::fromLatin1(buf).stripWhiteSpace();
-      QStringList split = QStringList::split(' ', line);
+      QString line = QString::fromLatin1(buf).trimmed();
+      const QStringList split = line.split(' ', QString::SkipEmptyParts);
       if (split.count() <= 1)
          return 1;
-         
+
       if (split[1] == "T")
       {
-         dict.insert(split[2], &i);  
+         dict.insert(split[2], &i);
       }
    }
    fclose(map_file);
-   
+
    FILE *call_file = fopen(argv[2], "r");
    if (!call_file)
    {
       fprintf(stderr, "Error opening '%s'\n", argv[2]);
       return 1;
    }
-   
+
    while(!feof(call_file))
    {
       fgets(buf, 1024, call_file);
-      QString line = QString::fromLatin1(buf).stripWhiteSpace();
+      QString line = QString::fromLatin1(buf).trimmed();
       if (dict.find(line))
       {
-         qWarning("%s", line.latin1());
+         qWarning("%s", qPrintable(line));
       }
    }
    fclose(call_file);
-   return 0; 
+   return 0;
 }
 
