@@ -18,8 +18,7 @@
 #ifndef DIFFERENCE_H
 #define DIFFERENCE_H
 
-#include <q3valuelist.h>
-#include <q3valuevector.h>
+#include <qvector.h>
 
 #include <kdebug.h>
 #include "diff2export.h"
@@ -29,7 +28,6 @@ class QString;
 namespace Diff2
 {
 
-class LevenshteinTable;
 
 class DIFF2_EXPORT Marker
 {
@@ -61,9 +59,9 @@ private:
 	unsigned int      m_offset;
 };
 
-typedef Q3ValueList<Marker*> MarkerList;
-typedef Q3ValueList<Marker*>::iterator MarkerListIterator;
-typedef Q3ValueList<Marker*>::const_iterator MarkerListConstIterator;
+typedef QList<Marker*> MarkerList;
+typedef QList<Marker*>::iterator MarkerListIterator;
+typedef QList<Marker*>::const_iterator MarkerListConstIterator;
 
 class DIFF2_EXPORT DifferenceString
 {
@@ -73,7 +71,7 @@ public:
 //		kDebug(8101) << "DifferenceString::DifferenceString()" << endl;
 	}
 	explicit DifferenceString( const QString& string, const MarkerList& markerList = MarkerList() ) :
-		m_string( string ), 
+		m_string( string ),
 		m_markerList( markerList )
 	{
 //		kDebug(8101) << "DifferenceString::DifferenceString( " << string << ", " << markerList << " )" << endl;
@@ -150,9 +148,9 @@ private:
 	MarkerList   m_markerList;
 };
 
-typedef Q3ValueVector<DifferenceString*> DifferenceStringList;
-typedef Q3ValueVector<DifferenceString*>::iterator DifferenceStringListIterator;
-typedef Q3ValueVector<DifferenceString*>::const_iterator DifferenceStringListConstIterator;
+typedef QVector<DifferenceString*> DifferenceStringList;
+typedef QVector<DifferenceString*>::iterator DifferenceStringListIterator;
+typedef QVector<DifferenceString*>::const_iterator DifferenceStringListConstIterator;
 
 class DIFF2_EXPORT Difference
 {
@@ -187,6 +185,15 @@ public:
 		m_conflicts = conflicts;
 	}
 
+	bool isUnsaved() const
+	{
+		return m_unsaved;
+	}
+	void setUnsaved( bool unsaved )
+	{
+		m_unsaved = unsaved;
+	}
+
 	void apply( bool apply );
 	bool applied() const { return m_applied; }
 
@@ -211,11 +218,12 @@ private:
 
 	bool                  m_applied;
 	bool                  m_conflicts;
+	bool                  m_unsaved;
 };
 
-typedef Q3ValueList<Difference*> DifferenceList;
-typedef Q3ValueList<Difference*>::iterator DifferenceListIterator;
-typedef Q3ValueList<Difference*>::const_iterator DifferenceListConstIterator;
+typedef QList<Difference*> DifferenceList;
+typedef QList<Difference*>::iterator DifferenceListIterator;
+typedef QList<Difference*>::const_iterator DifferenceListConstIterator;
 
 } // End of namespace Diff2
 
