@@ -16,8 +16,8 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  **/
 
 #include "kuiviewer.h"
@@ -26,14 +26,14 @@
 
 #include <kdebug.h>
 
-#include <qobjectlist.h>
-#include <qdockwindow.h>
+#include <qobject.h>
 #include <qpixmap.h>
 
 #include <kurl.h>
 
 #include <kaction.h>
-#include <kstdaction.h>
+#include <kactioncollection.h>
+#include <kstandardaction.h>
 
 #include <kiconloader.h>
 #include <klibloader.h>
@@ -42,8 +42,9 @@
 #include <kfiledialog.h>
 
 KUIViewer::KUIViewer()
-    : KParts::MainWindow( 0L, "KUIViewer" )
+    : KParts::MainWindow()
 {
+    setObjectName( "KUIViewer" );
     // setup our actions
     setupActions();
 
@@ -61,10 +62,11 @@ KUIViewer::KUIViewer()
         // now that the Part is loaded, we cast it to a Part to get
         // our hands on it
         m_part = static_cast<KParts::ReadOnlyPart *>(factory->create(this,
-                                "kuiviewer_part", "KParts::ReadOnlyPart" ));
+                                                     "KParts::ReadOnlyPart" ));
 
         if (m_part)
         {
+	    m_part->setObjectName( "kuiviewer_part" );
             // tell the KParts::MainWindow that this is indeed the main widget
             setCentralWidget(m_part->widget());
 
@@ -89,31 +91,16 @@ KUIViewer::~KUIViewer()
 {
 }
 
-void KUIViewer::load(const KURL& url)
+void KUIViewer::load(const KUrl& url)
 {
-    m_part->openURL( url );
+    m_part->openUrl( url );
     adjustSize();
 }
 
 void KUIViewer::setupActions()
 {
-    KStdAction::open(this, SLOT(fileOpen()), actionCollection());
-    KStdAction::quit(kapp, SLOT(quit()), actionCollection());
-}
-
-void KUIViewer::saveProperties(KConfig* /*config*/)
-{
-    // the 'config' object points to the session managed
-    // config file.  anything you write here will be available
-    // later when this app is restored
-}
-
-void KUIViewer::readProperties(KConfig* /*config*/)
-{
-    // the 'config' object points to the session managed
-    // config file.  this function is automatically called whenever
-    // the app is being restored.  read in here whatever you wrote
-    // in 'saveProperties'
+    KStandardAction::open(this, SLOT(fileOpen()), actionCollection());
+    KStandardAction::quit(kapp, SLOT(quit()), actionCollection());
 }
 
 void KUIViewer::fileOpen()
@@ -121,8 +108,8 @@ void KUIViewer::fileOpen()
     // this slot is called whenever the File->Open menu is selected,
     // the Open shortcut is pressed (usually CTRL+O) or the Open toolbar
     // button is clicked
-    KURL file_name =
-        KFileDialog::getOpenURL( QString::null, i18n("*.ui *.UI|User Interface Files"), this );
+    KUrl file_name =
+        KFileDialog::getOpenUrl( KUrl(), i18n("*.ui *.UI|User Interface Files"), this );
 
     if (file_name.isEmpty() == false)
     {
@@ -145,7 +132,7 @@ void KUIViewer::fileOpen()
     }
 }
 
-void KUIViewer::takeScreenshot(const QCString &filename, int w, int h){
+void KUIViewer::takeScreenshot(const QByteArray &filename, int w, int h){
     if(!m_part)
         return;
     showMinimized();
