@@ -1,12 +1,11 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2002-2008                                                *
- *  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                   *
+ *   copyright (C) 2002-2009                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 #ifndef CMD_HANDLE_RENAME_H
@@ -14,25 +13,23 @@
 
 #include <QtGui/QUndoCommand>
 
-#include "floatingtextwidget.h"
-
+class FloatingTextWidget;
 
 namespace Uml
 {
     class CmdHandleRename : public QUndoCommand
     {
-        //friend class FloatingTextWidget;
         public:
-            CmdHandleRename(FloatingTextWidget* _ftw, QString& txt);
+            CmdHandleRename(FloatingTextWidget* ftw, QString& txt);
             ~CmdHandleRename();
 
             void redo();
             void undo();
 
         private:
-            FloatingTextWidget*     ftw;
-            QString     newstring;
-            QString     oldstring;
+            FloatingTextWidget*  m_ftw;
+            QString     m_newstring;
+            QString     m_oldstring;
     };
 }
 
