@@ -1,116 +1,87 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2006                                               *
+ *   copyright (C) 2002-2008                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
-
 #ifndef UMLVIEWDIALOG_H
 #define UMLVIEWDIALOG_H
-//kde includes
-#include <kdialogbase.h>
-//app includes
+
+// qt includes
+
+// kde includes
+#include <kpagedialog.h>
+
+// app includes
 #include "classoptionspage.h"
 #include "umlwidgetcolorpage.h"
-#include "../optionstate.h"
+#include "optionstate.h"
+#include "ui_diagrampropertiespage.h"
+
+class UMLView;
+class KFontChooser;
 
 /**
  * @author Paul Hensgen
  * Bugs and comments to uml-devel@lists.sf.net or http://bugs.kde.org
  */
-class UMLView;
-class ClassWidget;
 
-class QCheckBox;
-class QLabel;
-class QLineEdit;
-class QGroupBox;
-class QTextEdit;
-class QSpinBox;
-class KFontChooser;
-class DiagramPropertiesPage;
+class DiagramPropertiesPage : public QWidget, public Ui::DiagramPropertiesPage
+{
+public:
+    DiagramPropertiesPage( QWidget *parent ) : QWidget( parent ) {
+        setupUi( this );
+  }
+};
 
 
-class UMLViewDialog : public KDialogBase {
+class UMLViewDialog : public KPageDialog
+{
     Q_OBJECT
 public:
+
     /**
-    *   Constructor
-    */
+     * Constructor
+     */
     UMLViewDialog( QWidget * pParent, UMLView * pView );
 
     /**
-    *   Deconstructor
-    */
+     * Deconstructor
+     */
     ~UMLViewDialog();
-protected:
-    enum Page
-    {
-        General = 0,
-        Color,
-        Font,
-        Class
-    };
 
-    /**
-    *   Sets up the dialog pages.
-    */
+protected:
+
     void setupPages();
 
-    /**
-    *   Sets up the general Diagram Properties Page
-    */
     void setupDiagramPropertiesPage();
 
-    /**
-    *   Sets up the Class page
-    */
     void setupClassPage();
 
-    /**
-    *   Sets up the color page.
-    */
     void setupColorPage();
 
-    /**
-    *   Sets up font page.
-    */
     void setupFontPage();
 
-    /**
-    *   Applys the properties of the given page.
-    */
-    void applyPage( Page page );
+    void applyPage( KPageWidgetItem* );
 
-    /**
-    *   Checks whether the name is unique and sets it if it is.
-    */
     void checkName();
 
     /**
-    *   The view to represent.
-    */
+     * The view to represent.
+     */
     UMLView * m_pView;
 
     Settings::OptionState m_options;
 
     KFontChooser * m_pChooser;
-    DiagramPropertiesPage *m_diagramProperties;
+    DiagramPropertiesPage * m_diagramProperties;
     ClassOptionsPage * m_pOptionsPage;
     UMLWidgetColorPage * m_pColorPage;
+    KPageWidgetItem *m_pageColorItem, *m_pageFontItem, *m_pageDisplayItem, *m_pageGeneralItem;
 
-    //GUI widgets
-    QLabel * m_pNameL, * m_pSpinXL, * m_pSpinYL;
-    QLineEdit * m_pNameLE;
-    QGroupBox * m_pDocGB, * m_pValuesGB;
-    QCheckBox * m_pSnapToGridCB, * m_pShowSnapCB;
-    QTextEdit * m_pDocTE;
-    QSpinBox * m_pSnapXSB, * m_pSnapYSB;
-    QSpinBox * m_pLineWidthSB;
 public slots:
     void slotOk();
     void slotApply();
